/*
 * Copyright (C) by Oleksandr Zolotov <alex@nextcloud.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 * for more details.
 */

#ifndef FOLDERCREATIONDIALOG_H
#define FOLDERCREATIONDIALOG_H

#include <QDialog>

namespace OCC {

namespace Ui {
class FolderCreationDialog;
}

class FolderCreationDialog : public QDialog
{
    Q_OBJECT

public:
    explicit FolderCreationDialog(const QString &destination, QWidget *parent = nullptr);
    ~FolderCreationDialog() override;

signals:
    void folderCreated(const QString &fullFolderPath);

private slots:
    void accept() override;

    void slotNewFolderNameEditTextEdited();

private:
    Ui::FolderCreationDialog *ui;

    QString _destination;
};

}

#endif // FOLDERCREATIONDIALOG_H
